%ROTX   Rotation about x
% Homogeneous transform for rotation about x axis
%
% Syntax:  T = rotx(theta)
%
% Inputs:
%    theta - angle to rotate about x
%
% Outputs:
%    T - homogeneous rotation transformation
%
% See also: ROTY,  ROTZ

% Author: Travis Hydzik
% Last revision: 19 October 2004

function T = rotx(theta)
	
	T = [ 1     0           0        0 
          0  cos(theta) -sin(theta)  0 
          0  sin(theta)  cos(theta)  0 
          0     0           0        1];

% alternatively
% T = rot([1 0 0], theta)